@@ -7,6 +7,7 @@
 package DTA::CAB::Format::Raw::Waste;
 use DTA::CAB::Format;
 use DTA::CAB::Format::TT;
+use DTA::CAB::Format::Raw::Base;
 use DTA::CAB::Datum ':all';
 use DTA::CAB::Utils qw(file_mtime timestamp_str);
 use IO::File;
@@ -20,7 +21,7 @@ use strict;
 ## Globals
 ##==============================================================================
 
-our @ISA = qw(DTA::CAB::Format);
+our @ISA = qw(DTA::CAB::Format::Raw::Base);
 
 BEGIN {
   DTA::CAB::Format->registerFormat(name=>__PACKAGE__, short=>'raw-waste', filenameRegex=>qr/\.(?i:raw-waste|txt-waste)$/);
@@ -54,6 +55,7 @@ our $logRun = undef;
 ##     ##-- Input
 ##     doc => $doc,                    ##-- buffered input document
 ##     wasterc => $rcFile,             ##-- waste .rc file; default: "$HOME/.wasterc" || "/etc/wasterc" || "/etc/default/waste"
+##     tloc => $attr,                  ##-- pased to Format::TT::parseTokenizerString(): if non-empty, sets $w->{$attr}="$off $len"; default=0
 ##
 ##     ##-- Runtime
 ##     wmodel => \%wmodel              ##-- waste model; %wmodel=(
@@ -83,6 +85,7 @@ sub new {
 		   ##-- input
 		   doc => undef,
 		   wasterc => undef,
+		   tloc => undef,
 
 		   ##-- runtime
 		   wmodel => undef,
@@ -306,7 +309,7 @@ sub fromFh {
 
   ##-- construct & buffer document
   utf8::decode($ttstr) if (!utf8::is_utf8($ttstr));
-  $fmt->{doc} = DTA::CAB::Format::TT->parseTokenizerString(\$ttstr);
+  $fmt->{doc} = DTA::CAB::Format::TT->parseTokenizerString(\$ttstr, {tloc=>$fmt->{tloc}});
   return $fmt;
 }
 
@@ -342,9 +345,6 @@ __END__
 
 ##========================================================================
 ## POD DOCUMENTATION, auto-generated by podextract.perl
-=pod
-
-=cut
 
 ##========================================================================
 ## NAME
@@ -415,6 +415,14 @@ DTA::CAB::Format::Raw::Waste - Datum parser: raw untokenized text (using moot/wa
 
 =head1 DESCRIPTION
 
+DTA::CAB::Format::Raw::Waste
+is an input L<DTA::CAB::Format|DTA::CAB::Format> subclass
+for untokenized raw string input using
+L<mootE<sol>WASTE|http://www.dwds.de/waste> as an underlying tokenizer.
+As an output format,
+inherits from L<DTA::CAB::Format::Raw::Base|DTA::CAB::Format::Raw::Base> for output.
+
+
 =cut
 
 ##----------------------------------------------------------------
@@ -427,11 +435,11 @@ DTA::CAB::Format::Raw::Waste - Datum parser: raw untokenized text (using moot/wa
 
 =item Variable: @ISA
 
-Inherits from L<DTA::CAB::Format|DTA::CAB::Format>.
+Inherits from L<DTA::CAB::Format::Raw::Base|DTA::CAB::Format::Raw::Base>.
 
 =item Variable: @DEFAULT_WASTERC_PATHS
 
-List of default paths to search for waste.rc config files; see L<mootfiles|mootfiles(5)>;
+List of default paths to search for waste.rc config files; see L<mootfiles(5)|man://mootfiles>;
 default value:
 
  ($ENV{TOKWRAP_RCDIR} ? "$ENV{TOKWRAP_RCDIR}/waste/waste.rc" : qw()),
@@ -562,7 +570,7 @@ ensures model is loaded.
  $fmt_or_undef = $fmt->loadModel();
  $fmt_or_undef = $fmt->loadModel($rcfile);
 
-backwards-compatible method wraps L<ensureModel|ensureModel()>.
+backwards-compatible method wraps C<ensureModel()>.
 
 =back
 
@@ -636,11 +644,6 @@ returns default filename extension for this format (C<.raw>)
 
 ##========================================================================
 ## END POD DOCUMENTATION, auto-generated by podextract.perl
-=pod
-
-
-
-=cut
 
 ##======================================================================
 ## Footer
